Class: RuboCop::Cop::Style::RbsInline::StructNewWithBlock
- Inherits:
-
Base
- Object
- Base
- RuboCop::Cop::Style::RbsInline::StructNewWithBlock
- Includes:
- ASTUtils, FileFilter, StructClassMatcher
- Defined in:
- lib/rubocop/cop/style/rbs_inline/struct_new_with_block.rb,
sig/rubocop/cop/style/rbs_inline/struct_new_with_block.rbs
Overview
Checks for Struct.new calls with a block.
RBS::Inline does not parse the contents of Struct.new blocks, so any
methods defined inside will not be recognized for type checking. Instead,
call Struct.new without a block and define additional methods by
reopening the class separately.
Constant Summary collapse
- MSG =
"Do not use `Struct.new` with a block. RBS::Inline does not parse block contents, " \ "so methods defined in the block will not be recognized. Keep the `Struct.new` call " \ "and move the methods into %<destination>s."
Constants included from FileFilter
FileFilter::MAGIC_COMMENT_DISABLED, FileFilter::MAGIC_COMMENT_ENABLED
Constants included from ModeConfig
Instance Method Summary collapse
-
#destination(node) ⇒ String
The constant the definition is assigned to is the class to reopen.
- #on_send(node) ⇒ void
Methods included from ASTUtils
#args_node_for, #assigned_constant_name, #end_line, #method_parameter_list_end_line, #name_location, #source!, #value_to_sym
Methods included from StructClassMatcher
#attr_argument?, #struct_like_class?
Methods included from FileFilter
#add_offense, #on_new_investigation, #rbs_inline_disabled?, #rbs_inline_enabled?, #rbs_inline_file_skipped?, #skip_by_mode?
Methods included from ModeConfig
#configured_mode, #validate_config
Instance Method Details
#destination(node) ⇒ String
The constant the definition is assigned to is the class to reopen.
50 51 52 53 54 55 |
# File 'lib/rubocop/cop/style/rbs_inline/struct_new_with_block.rb', line 50 def destination(node) #: String class_name = assigned_constant_name(node) return "a `class` that reopens it" unless class_name "`class #{class_name} ... end` written after it" end |
#on_send(node) ⇒ void
This method returns an undefined value.
37 38 39 40 41 42 43 44 |
# File 'lib/rubocop/cop/style/rbs_inline/struct_new_with_block.rb', line 37 def on_send(node) #: void return unless struct_like_class?(node) block_node = node.parent return unless block_node&.block_type? add_offense(node, message: format(MSG, destination: destination(block_node))) end |