Class: RuboCop::Cop::Style::RbsInline::DataDefineWithBlock
- Inherits:
-
Base
- Object
- Base
- RuboCop::Cop::Style::RbsInline::DataDefineWithBlock
- Includes:
- DataClassMatcher, FileFilter
- Defined in:
- lib/rubocop/cop/style/rbs_inline/data_define_with_block.rb,
sig/rubocop/cop/style/rbs_inline/data_define_with_block.rbs
Overview
Checks for Data.define calls with a block.
RBS::Inline does not parse the contents of Data.define blocks, so any
methods defined inside will not be recognized for type checking. Instead,
call Data.define without a block and define additional methods by
reopening the class separately.
NOTE: This is a known limitation of RBS::Inline. See https://github.com/soutaro/rbs-inline/pull/183 for the upstream fix.
Constant Summary collapse
- MSG =
"Do not use `Data.define` with a block. RBS::Inline does not parse block contents, " \ "so methods defined in the block will not be recognized. " \ "Use a separate class definition instead."
Constants included from FileFilter
FileFilter::MAGIC_COMMENT_DISABLED, FileFilter::MAGIC_COMMENT_ENABLED, FileFilter::SUPPORTED_MODES
Instance Method Summary collapse
Methods included from DataClassMatcher
Methods included from FileFilter
#add_offense, #configured_mode, #on_new_investigation, #rbs_inline_disabled?, #rbs_inline_enabled?, #rbs_inline_file_skipped?, #skip_by_mode?, warn_invalid_mode
Instance Method Details
#on_send(node) ⇒ void
This method returns an undefined value.
39 40 41 42 43 44 45 46 |
# File 'lib/rubocop/cop/style/rbs_inline/data_define_with_block.rb', line 39 def on_send(node) #: void return unless struct_like_class?(node) block_node = node.parent return unless block_node&.block_type? add_offense(node) end |